@@ -1,6 +1,6 @@
-#==============================================================================
+# ==============================================================================
 # Persian Calendar
-#==============================================================================
+# ==============================================================================
 
 PERSIAN_EPOCH <- 226896 # vec_data(julian_date(ce(622), MARCH, 19))
 TEHRAN <- location(angle(35.68, 0, 0), angle(51.42, 0, 0), mt(1100), 3.5)
@@ -11,7 +11,9 @@ fixed_from_persian <- function(p_date) {
   new_year[!miss] <- persian_new_year_on_or_before(
     PERSIAN_EPOCH +
       180 +
-      floor(MEAN_TROPICAL_YEAR * (p_date$year[!miss] - (p_date$year[!miss] > 0)))
+      floor(
+        MEAN_TROPICAL_YEAR * (p_date$year[!miss] - (p_date$year[!miss] > 0))
+      )
   )
   new_year -
     1 + # Days in prior years
@@ -30,7 +32,9 @@ persian_from_fixed <- function(date) {
   year <- y - (y <= 0) # No year zero
   day_of_year <- 1 + date - vec_data(persian_date(year, 1, 1))
   month <- ceiling(day_of_year / 31)
-  month[day_of_year > 186 & !miss] <- ceiling((day_of_year[day_of_year > 186 & !miss] - 6) / 30)
+  month[day_of_year > 186 & !miss] <- ceiling(
+    (day_of_year[day_of_year > 186 & !miss] - 6) / 30
+  )
   day <- date - (vec_data(persian_date(year, month, 1)) - 1)
 
   list(year = year, month = month, day = trunc(day))
@@ -59,7 +63,9 @@ arithmetic_persian_from_fixed <- function(date) {
     date -
     vec_data(apersian_date(year, 1, 1))
   month <- ceiling(day_of_year / 31)
-  month[day_of_year > 186 & !miss] <- ceiling((day_of_year[day_of_year > 186 & !miss] - 6) / 30)
+  month[day_of_year > 186 & !miss] <- ceiling(
+    (day_of_year[day_of_year > 186 & !miss] - 6) / 30
+  )
   day <- date -
     (vec_data(apersian_date(year, month, 1)) - 1)
   list(year = year, month = month, day = trunc(day))
@@ -133,7 +139,7 @@ cal_apersian <- new_calendar(
 #' @param day Numeric vector of days
 #' @return A persian vector object
 #' @examples
-#' gregorian_date(2025,5,1:20) |>
+#' gregorian_date(2025, 5, 1:20) |>
 #'   as_persian()
 #'
 #' @export
